@@ -7,10 +7,7 @@ testing.py unit test module support classes and functions
 
 
 import sys
-if sys.version_info < (2, 7):
-    import unittest2 as unittest
-else:
-    import unittest
+import unittest
 
 import os
 import importlib
